@@ -14,7 +14,6 @@ import click
 from fido2.ctap import CtapError
 
 import solo
-from solo.helpers import enter_bootloader_or_die
 
 
 @click.group()
@@ -167,14 +166,14 @@ def bootloader(serial, firmware):
         else:
             raise e
 
-        enter_bootloader_or_die(p)
+        p.enter_bootloader_or_die()
 
         print("Solo rebooted.  Reconnecting...")
         time.sleep(0.5)
         p = solo.client.find(serial)
         if p is None:
             print("Cannot find Solo device.")
-            return -1
+            sys.exit(1)
         p.use_hid()
         p.program_file(firmware)
 
@@ -202,7 +201,7 @@ def enter_bootloader(serial):
 
     p = solo.client.find(serial)
 
-    enter_bootloader_or_die(p)
+    p.enter_bootloader_or_die()
 
     print("Solo rebooted.  Reconnecting...")
     time.sleep(0.5)
